# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: redislite.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fredislite.proto\x12\tredislite\"$\n\x0bInitRequest\x12\x15\n\rconnection_id\x18\x01 \x01(\t\"\x1b\n\tInitReply\x12\x0e\n\x06status\x18\x01 \x01(\t\"(\n\nSetRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x1a\n\x08SetReply\x12\x0e\n\x06status\x18\x01 \x01(\t\"\x19\n\nGetRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\")\n\x08GetReply\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t2\xbd\x01\n\x0fRedisLiteServer\x12@\n\x0eInitConnection\x12\x16.redislite.InitRequest\x1a\x14.redislite.InitReply\"\x00\x12\x33\n\x03Set\x12\x15.redislite.SetRequest\x1a\x13.redislite.SetReply\"\x00\x12\x33\n\x03Get\x12\x15.redislite.GetRequest\x1a\x13.redislite.GetReply\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'redislite_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_INITREQUEST']._serialized_start=30
  _globals['_INITREQUEST']._serialized_end=66
  _globals['_INITREPLY']._serialized_start=68
  _globals['_INITREPLY']._serialized_end=95
  _globals['_SETREQUEST']._serialized_start=97
  _globals['_SETREQUEST']._serialized_end=137
  _globals['_SETREPLY']._serialized_start=139
  _globals['_SETREPLY']._serialized_end=165
  _globals['_GETREQUEST']._serialized_start=167
  _globals['_GETREQUEST']._serialized_end=192
  _globals['_GETREPLY']._serialized_start=194
  _globals['_GETREPLY']._serialized_end=235
  _globals['_REDISLITESERVER']._serialized_start=238
  _globals['_REDISLITESERVER']._serialized_end=427
# @@protoc_insertion_point(module_scope)
